summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoTextParag.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoTextParag.cpp')
-rw-r--r--lib/kotext/KoTextParag.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/lib/kotext/KoTextParag.cpp b/lib/kotext/KoTextParag.cpp
index 633bdb58..23754c28 100644
--- a/lib/kotext/KoTextParag.cpp
+++ b/lib/kotext/KoTextParag.cpp
@@ -1229,7 +1229,7 @@ void KoTextParag::drawLabel( TQPainter* p, int xLU, int yLU, int /*wLU*/, int /*
else
{
TQString counterText = m_layout.counter->text( this );
// There are no bullets...any tqparent bullets have already been suppressed.
// Just draw the text! Note: one space is always appended.
if ( !counterText.isEmpty() )
{
@@ -2708,7 +2708,7 @@ static TQString normalizeWhitespace( const TQString& in, bool leadingSpace )
// check for space, tab, line feed, carriage return
if ( ch == ' ' || ch == '\t' ||ch == '\r' || ch == '\n')
{
- // if we were lead by whitespace in some tqparent or previous sibling element,
+ // if we were lead by whitespace in some parent or previous sibling element,
// we completely collapse this space
if ( r != 0 || !leadingSpace )
text[w++] = TQChar( ' ' );
@@ -2733,19 +2733,19 @@ static TQString normalizeWhitespace( const TQString& in, bool leadingSpace )
return text;
}
-void KoTextParag::loadOasisSpan( const TQDomElement& tqparent, KoOasisContext& context, uint& pos, bool stripLeadingSpace )
+void KoTextParag::loadOasisSpan( const TQDomElement& parent, KoOasisContext& context, uint& pos, bool stripLeadingSpace )
{
bool dummy;
- return loadOasisSpan( tqparent, context, pos, stripLeadingSpace, &dummy );
+ return loadOasisSpan( parent, context, pos, stripLeadingSpace, &dummy );
}
-void KoTextParag::loadOasisSpan( const TQDomElement& tqparent, KoOasisContext& context, uint& pos, bool stripLeadingSpace, bool *hasTrailingSpace )
+void KoTextParag::loadOasisSpan( const TQDomElement& parent, KoOasisContext& context, uint& pos, bool stripLeadingSpace, bool *hasTrailingSpace )
{
// Parse every child node of the tqparent
// Can't use forEachElement here since we also care about text nodes
TQDomNode node;
- for ( node = tqparent.firstChild(); !node.isNull(); node = node.nextSibling() )
+ for ( node = parent.firstChild(); !node.isNull(); node = node.nextSibling() )
{
TQDomElement ts = node.toElement();
TQString textData;
@@ -2772,7 +2772,7 @@ void KoTextParag::loadOasisSpan( const TQDomElement& tqparent, KoOasisContext& c
// should only have one space between each of "Foo", "Bar", and "Baz"
// so we need to keep track of whether there was any trailing whitespace
// in sub-spans so that we can propogate the whitespace compression state
// back up to the tqparent element
loadOasisSpan( ts, context, pos, stripLeadingSpace, hasTrailingSpace ); // recurse
stripLeadingSpace = *hasTrailingSpace;
context.styleStack().restore();
@@ -2885,7 +2885,7 @@ KoParagLayout KoTextParag::loadParagLayout( KoOasisContext& context, KoStyleColl
return tqlayout;
}
-void KoTextParag::loadOasis( const TQDomElement& tqparent, KoOasisContext& context, KoStyleCollection *styleCollection, uint& pos )
+void KoTextParag::loadOasis( const TQDomElement& parent, KoOasisContext& context, KoStyleCollection *styleCollection, uint& pos )
{
// First load tqlayout from style
KoParagLayout paragLayout = loadParagLayout( context, styleCollection, true );
@@ -2898,7 +2898,7 @@ void KoTextParag::loadOasis( const TQDomElement& tqparent, KoOasisContext& conte
// Load text
// OO.o compatibility: ignore leading whitespace in <p> and <h> elements
- loadOasisSpan( tqparent, context, pos, true );
+ loadOasisSpan( parent, context, pos, true );
// Apply default format to trailing space
const int len = str->length();
@@ -2915,7 +2915,7 @@ void KoTextParag::saveOasis( KoXmlWriter& writer, KoSavingContext& context,
{
KoGenStyles& mainStyles = context.mainStyles();
// Write paragtqlayout to styles (with tqparent == the parag's style)
TQString parentStyleName;
if ( m_layout.style )
parentStyleName = m_layout.style->name();
@@ -3059,7 +3059,7 @@ void KoTextParag::saveOasis( KoXmlWriter& writer, KoSavingContext& context,
{
lastFormatRaw = newFormat;
// Remove isMisspelled from format, to avoid useless derived styles
// (which would be indentical to their tqparent style)
KoTextFormat tmpFormat( *newFormat );
tmpFormat.setMisspelled( false );
newFormat = formatCollection()->format( &tmpFormat );
@@ -1229,7 +1229,7 @@ void KoTextParag::drawLabel( TQPainter* p, int xLU, int yLU, int /*wLU*/, int /*
{
TQString counterText = m_layout.counter->text( this );
- // There are no bullets...any tqparent bullets have already been suppressed.
+ // There are no bullets...any parent bullets have already been suppressed.
// Just draw the text! Note: one space is always appended.
if ( !counterText.isEmpty() )
@@ -2733,19 +2733,19 @@ static TQString normalizeWhitespace( const TQString& in, bool leadingSpace )
{
- // Parse every child node of the tqparent
+ // Parse every child node of the parent
// Can't use forEachElement here since we also care about text nodes
TQDomNode node;
@@ -2772,7 +2772,7 @@ void KoTextParag::loadOasisSpan( const TQDomElement& tqparent, KoOasisContext& c
// so we need to keep track of whether there was any trailing whitespace
// in sub-spans so that we can propogate the whitespace compression state
- // back up to the tqparent element
+ // back up to the parent element
loadOasisSpan( ts, context, pos, stripLeadingSpace, hasTrailingSpace ); // recurse
stripLeadingSpace = *hasTrailingSpace;
@@ -2915,7 +2915,7 @@ void KoTextParag::saveOasis( KoXmlWriter& writer, KoSavingContext& context,
{
KoGenStyles& mainStyles = context.mainStyles();
- // Write paragtqlayout to styles (with tqparent == the parag's style)
+ // Write paragtqlayout to styles (with parent == the parag's style)
TQString parentStyleName;
if ( m_layout.style )
@@ -3059,7 +3059,7 @@ void KoTextParag::saveOasis( KoXmlWriter& writer, KoSavingContext& context,
lastFormatRaw = newFormat;
// Remove isMisspelled from format, to avoid useless derived styles
- // (which would be indentical to their tqparent style)
+ // (which would be indentical to their parent style)
KoTextFormat tmpFormat( *newFormat );
tmpFormat.setMisspelled( false );